==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/ImageTagListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageTagListBuilder extends io.fabric8.openshift.api.model.ImageTagListFluentImpl<io.fabric8.openshift.api.model.ImageTagListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ImageTagList,io.fabric8.openshift.api.model.ImageTagListBuilder>{
  public ImageTagListBuilder() {
    this(false);
  }
  public ImageTagListBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageTagList(), validationEnabled);
  }
  public ImageTagListBuilder(io.fabric8.openshift.api.model.ImageTagListFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageTagListBuilder(io.fabric8.openshift.api.model.ImageTagListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageTagList(), validationEnabled);
  }
  public ImageTagListBuilder(io.fabric8.openshift.api.model.ImageTagListFluent<?> fluent,io.fabric8.openshift.api.model.ImageTagList instance) {
    this(fluent, instance, false);
  }
  public ImageTagListBuilder(io.fabric8.openshift.api.model.ImageTagListFluent<?> fluent,io.fabric8.openshift.api.model.ImageTagList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageTagListBuilder(io.fabric8.openshift.api.model.ImageTagList instance) {
    this(instance,false);
  }
  public ImageTagListBuilder(io.fabric8.openshift.api.model.ImageTagList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ImageTagListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ImageTagList build() {
    ImageTagList buildable = new ImageTagList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageTagListBuilder that = (ImageTagListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.3.0-sources.jar: io/fabric8/openshift/api/model/ImageTagListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageTagListBuilder extends ImageTagListFluentImpl<ImageTagListBuilder> implements VisitableBuilder<ImageTagList,ImageTagListBuilder>{
  public ImageTagListBuilder() {
    this(false);
  }
  public ImageTagListBuilder(Boolean validationEnabled) {
    this(new ImageTagList(), validationEnabled);
  }
  public ImageTagListBuilder(ImageTagListFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageTagListBuilder(ImageTagListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ImageTagList(), validationEnabled);
  }
  public ImageTagListBuilder(ImageTagListFluent<?> fluent,ImageTagList instance) {
    this(fluent, instance, false);
  }
  public ImageTagListBuilder(ImageTagListFluent<?> fluent,ImageTagList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageTagListBuilder(ImageTagList instance) {
    this(instance,false);
  }
  public ImageTagListBuilder(ImageTagList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ImageTagListFluent<?> fluent;
  Boolean validationEnabled;
  public ImageTagList build() {
    ImageTagList buildable = new ImageTagList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
